==> DIYPloneStyle-2.1.3.tar.gz: DIYPloneStyle/bin/generator.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

import os, sys, optparse

# command line parser
parser = optparse.OptionParser()

parser.add_option('-p','--productname',
    action='store',
    dest='productname',
    help="Name that will be given to the product")

parser.add_option('--skindir',
    action='store',
    dest='skindir',
    help="Basename for the folders in the product 'skins/' directory")

parser.add_option('--skinname',
    action='store',
    dest='skinname',
    help="Name of the skin selection that will be added to 'portal_skins'")

parser.add_option('--stylesheet',
    action='store',
    dest='stylesheet',
    help="Name of the future stylesheet file")

parser.add_option('--enable-public-stylesheets',
    action='store_true',
    dest='enable_public',
    help="Keep default Plone public look.")

parser.add_option('-v', '--verbose',
    action="store_true",
    dest="verbose",
    help="Verbose mode")

parser.add_option('-r', '--replace',
    action="store_true",
    dest="replace",
    help="Replace original")


options, args = parser.parse_args()

path = os.path.dirname( os.path.abspath(__file__) )
if path.endswith('DIYPloneStyle%sbin' % os.sep):
    path = path[:-3]
else:
    raise IOError, 'This script must be in the DIYPloneStyle%sbin/ directory.' % os.sep


# Output help if no argument is given while calling the script
if not options.productname and len(args) != 1 or not os.path.isdir(path):
    parser.parse_args(args=['-h'])

PRODUCTNAME = options.productname or args[0]
SKINDIR = options.skindir or PRODUCTNAME.lower()
skinname = options.skinname or PRODUCTNAME
SKINNAME = skinname.replace('"', "'")

# check for valid product name
if PRODUCTNAME[0] in '0123456789':
    raise IOError, "Product name cannot start with a digit"
else:
    pass

stylesheet = options.stylesheet or '%s.css' % PRODUCTNAME.lower()
if stylesheet.endswith('.dtml'):
    stylesheet = stylesheet[:-5]
if not stylesheet.endswith('.css'):
    stylesheet = '%s.css' % stylesheet
STYLESHEET = stylesheet

ENABLE_PUBLIC_STYLESHEETS = options.enable_public

REPLACE_ORIGINAL = options.replace

PRODUCT_AUTHOR = 'John Doe <john.doe@dev.null>'
TEXT_FILES = {
    'HISTORY.txt': '''Changelog for %s

    (name of developer listed in brackets)

%s 1.0 - Unreleased

    - Generated skeleton product from DIYPloneStyle.
      [generator]
''' % ( PRODUCTNAME, PRODUCTNAME ),
    'README.txt': '''Description

    %s is a product that adds a new style to a Plone 2.1.x portal.
    It adds a new skin selection to the 'portal_skins' tool
    (called %s), and registers a custom stylesheet (called %s)
    with the 'portal_css' tool.

    %s is based on DIYPloneStyle 2.1, a skeleton product
    ready for building new graphical designs for Plone.

Installation

    Place %s in the Products directory of your Zope instance
    and restart the server.

    Go to the 'Site Setup' page in the Plone interface and click on the
    'Add/Remove Products' link.

    Choose %s (check its checkbox) and click the 'Install' button.

    You may have to empty your browser cache to see the effects of the
    product installation/uninstallation.

    Uninstall -- This can be done from the same management screen.

Selecting a skin

   Depending on the value given to SELECTSKIN (in config.py), the skin will be
   selected (or not) as default one while installing the product. If you need
   to switch from a default skin to another, go to the 'Site Setup' page, and
   choose 'Skins' (as portal manager). You can also decide from that page if
   members can choose their preferred skin and, in that case, if the skin
   cookie should be persistent.

   Note -- Don't forget to perform a full refresh of the page or reload all
   images (not from browser cache) after selecting a skin.
   In Firefox, you can do so by pressing the 'shift' key while reloading the
   page. In IE, use the key combination <Ctrl-F5>.

Written by

    %s
''' % ( PRODUCTNAME, SKINNAME, STYLESHEET, PRODUCTNAME, PRODUCTNAME,
        PRODUCTNAME, PRODUCT_AUTHOR ),
    'version.txt': '1.0',
   }

UNWANTED_TEXT_LINES = (
    '''# CHANGE 'DIYPloneStyle' to your product name in the following lines''',
    ''''layers': ("diystyle_base_templates",''',
    '''"diystyle_base_images",''',
    '''"diystyle_base_styles"),''',
    '''{'name': "DIY Style Example",''',
    ''''layers': ("diystyle_example_templates",''',
    '''"diystyle_example_images",''',
    '''"diystyle_example_styles"),''',
   )

UNWANTED_FOLDERS_AND_FILES = (
    'bin',
    'diystyle_example_templates',
    'diystyle_example_images',
    'diystyle_example_styles',
    )

UNWANTED_FILE_EXTENSIONS = ('.pyc', '.pyo', '.swp', )
UNWANTED_FILE_PREFIXES = ('.', '#', )

FILE_MAPPING = (
    ('diystyle_base_styles', '%s_styles' % SKINDIR),
    ('diystyle_base_images', '%s_images' % SKINDIR),
    ('diystyle_base_templates', '%s_templates' % SKINDIR),
    ('diystylesheet.css.dtml', '%s.dtml' % STYLESHEET),
   )

CODE_EXTENSIONS = ('.py', '.dtml', '.props')
CODE_MAPPING = (
    ('DIYPloneStyle', PRODUCTNAME),
    ('DIY Style Base', SKINNAME),
    ('DIY Style Example', SKINNAME),
    ('diystylesheet.css', STYLESHEET),
    ('David Convent <davconvent@gmail.com>', PRODUCT_AUTHOR),
    ('diystyle', SKINDIR),
   )

DISABLE_STYLESHEETS = (
    'base.css.dtml',
    'public.css.dtml',
    'generated.css.dtml',
    'portlets.css.dtml',
    )

def log(message):
    if options.verbose:
        print >> sys.stdout, message

# Remove directory
def rmdir(dirname):
    log('Remove directory %s' % dirname)
    if os.path.isdir( dirname ):
        for filename in os.listdir(dirname):
            filepath = os.path.join(dirname, filename)
            if os.path.isfile(filepath):
                os.remove(os.path.join(dirname, filename))
            else:
                rmdir(filepath)
        os.rmdir(dirname)

# Test if the item must be kept in the new product.
def isItemKept(item):
    if item in UNWANTED_FOLDERS_AND_FILES: return False
    for unwanted in UNWANTED_FILE_EXTENSIONS:
        if item.endswith(unwanted): return False
    for unwanted in UNWANTED_FILE_PREFIXES:
        if item.startswith(unwanted): return False
    return True

# Recursive copy of a folder content 
def generateDirectoryCopy(srcDirectory, dstDirectory):
    if not os.path.exists(dstDirectory):
        os.mkdir(dstDirectory)
        log('Created directory %s' % dstDirectory)
    for item in os.listdir(srcDirectory):
        if isItemKept(item):
            # Get the name of the copied item in the new product.
            dst_item = item
            for src, dst in FILE_MAPPING:
                if dst_item.endswith(src):
                    dst_item = dst_item.strip(src) + dst
            # Get source and dest paths
            src_path = os.path.join(srcDirectory, item)
            dst_path = os.path.join(dstDirectory, dst_item)
            # Read, modify and write to destination if item is a file
            if os.path.isfile(src_path):
                # Read source file
                f_src = open(src_path,'r')
                data = f_src.read()
                f_src.close()
                # Full text replacement
                if item in TEXT_FILES.keys():
                    data = TEXT_FILES[item]
                # Code subsitutions
                f,ext = os.path.splitext(item)
                if ext in CODE_EXTENSIONS or item in ('LICENSE.txt',):
                    # Remove unwanted lines
                    lines = [ line for line in data.split('\n')
                              if line.strip() not in UNWANTED_TEXT_LINES ]
                    # Remove duplicates in config
                    if item == 'config.py':
                        del lines[17:19]
                    data = '\n'.join(lines)
                    # Replace PRODUCTNAME, SKINNAME, etc.
                    for orig, dest in CODE_MAPPING:
                        data = data.replace(orig, dest)
                # Write destination file
                f_dst = open(dst_path,'w')
                f_dst.write(data)
                f_dst.close()
                log('Created file %s' % dst_path)
                # Create empty disabled stylesheets
                if item == 'diystylesheet.css.dtml':
                    if not ENABLE_PUBLIC_STYLESHEETS:
                        for dcss in DISABLE_STYLESHEETS:
                            dst_path = os.path.join(dstDirectory, dcss)
                            f_dst = open(dst_path,'w')
                            f_dst.write(data)
                            f_dst.close()
                            log('Created empty %s' % dcss)

            # Create and copy content if item is a folder
            elif os.path.isdir(src_path):
                if not os.path.exists(dst_path):
                    os.mkdir(dst_path)
                    log('Created directory %s' % dst_path)
                generateDirectoryCopy(src_path, dst_path)


generateDirectoryCopy( path, path.replace('DIYPloneStyle', PRODUCTNAME) )
log('Created %s based on DIYPloneStyle.' % PRODUCTNAME)

if REPLACE_ORIGINAL:
    rmdir( os.path.join(path.strip('DIYPloneStyle'), 'DIYPloneStyle') )
    log('Removed DIYPloneStyle.')

log('%s product generated successfully.' % PRODUCTNAME)

==> DIYPloneStyle-2.1.4.tar.gz: DIYPloneStyle/bin/generator.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

import os, sys, optparse

# command line parser
parser = optparse.OptionParser()

parser.add_option('-p','--productname',
    action='store',
    dest='productname',
    help="Name that will be given to the product")

parser.add_option('--skindir',
    action='store',
    dest='skindir',
    help="Basename for the folders in the product 'skins/' directory")

parser.add_option('--skinname',
    action='store',
    dest='skinname',
    help="Name of the skin selection that will be added to 'portal_skins'")

parser.add_option('--stylesheet',
    action='store',
    dest='stylesheet',
    help="Name of the future stylesheet file")

parser.add_option('--enable-public-stylesheets',
    action='store_true',
    dest='enable_public',
    help="Keep default Plone public look.")

parser.add_option('-v', '--verbose',
    action="store_true",
    dest="verbose",
    help="Verbose mode")

parser.add_option('-r', '--replace',
    action="store_true",
    dest="replace",
    help="Replace original")


options, args = parser.parse_args()

path = os.path.dirname( os.path.abspath(__file__) )
if path.endswith('DIYPloneStyle%sbin' % os.sep):
    path = path[:-3]
else:
    raise IOError, 'This script must be in the DIYPloneStyle%sbin/ directory.' % os.sep


# Output help if no argument is given while calling the script
if not options.productname and len(args) != 1 or not os.path.isdir(path):
    parser.parse_args(args=['-h'])

PRODUCTNAME = options.productname or args[0]
SKINDIR = options.skindir or PRODUCTNAME.lower()
skinname = options.skinname or PRODUCTNAME
SKINNAME = skinname.replace('"', "'")

# check for valid product name
if PRODUCTNAME[0] in '0123456789':
    raise IOError, "Product name cannot start with a digit"
else:
    pass

stylesheet = options.stylesheet or '%s.css' % PRODUCTNAME.lower()
if stylesheet.endswith('.dtml'):
    stylesheet = stylesheet[:-5]
if not stylesheet.endswith('.css'):
    stylesheet = '%s.css' % stylesheet
STYLESHEET = stylesheet

ENABLE_PUBLIC_STYLESHEETS = options.enable_public

REPLACE_ORIGINAL = options.replace

PRODUCT_AUTHOR = 'John Doe <john.doe@dev.null>'
TEXT_FILES = {
    'HISTORY.txt': '''Changelog for %s

    (name of developer listed in brackets)

%s 1.0 - Unreleased

    - Generated skeleton product from DIYPloneStyle.
      [generator]
''' % ( PRODUCTNAME, PRODUCTNAME ),
    'README.txt': '''Description

    %s is a product that adds a new style to a Plone 2.1.x portal.
    It adds a new skin selection to the 'portal_skins' tool
    (called %s), and registers a custom stylesheet (called %s)
    with the 'portal_css' tool.

    %s is based on DIYPloneStyle 2.1, a skeleton product
    ready for building new graphical designs for Plone.

Installation

    Place %s in the Products directory of your Zope instance
    and restart the server.

    Go to the 'Site Setup' page in the Plone interface and click on the
    'Add/Remove Products' link.

    Choose %s (check its checkbox) and click the 'Install' button.

    You may have to empty your browser cache to see the effects of the
    product installation/uninstallation.

    Uninstall -- This can be done from the same management screen.

Selecting a skin

   Depending on the value given to SELECTSKIN (in config.py), the skin will be
   selected (or not) as default one while installing the product. If you need
   to switch from a default skin to another, go to the 'Site Setup' page, and
   choose 'Skins' (as portal manager). You can also decide from that page if
   members can choose their preferred skin and, in that case, if the skin
   cookie should be persistent.

   Note -- Don't forget to perform a full refresh of the page or reload all
   images (not from browser cache) after selecting a skin.
   In Firefox, you can do so by pressing the 'shift' key while reloading the
   page. In IE, use the key combination <Ctrl-F5>.

Written by

    %s
''' % ( PRODUCTNAME, SKINNAME, STYLESHEET, PRODUCTNAME, PRODUCTNAME,
        PRODUCTNAME, PRODUCT_AUTHOR ),
    'version.txt': '1.0',
   }

UNWANTED_TEXT_LINES = (
    '''# CHANGE 'DIYPloneStyle' to your product name in the following lines''',
    ''''layers': ("diystyle_base_templates",''',
    '''"diystyle_base_images",''',
    '''"diystyle_base_styles"),''',
    '''{'name': "DIY Style Example",''',
    ''''layers': ("diystyle_example_templates",''',
    '''"diystyle_example_images",''',
    '''"diystyle_example_styles"),''',
   )

UNWANTED_FOLDERS_AND_FILES = (
    'bin',
    'diystyle_example_templates',
    'diystyle_example_images',
    'diystyle_example_styles',
    )

UNWANTED_FILE_EXTENSIONS = ('.pyc', '.pyo', '.swp', )
UNWANTED_FILE_PREFIXES = ('.', '#', )

FILE_MAPPING = (
    ('diystyle_base_styles', '%s_styles' % SKINDIR),
    ('diystyle_base_images', '%s_images' % SKINDIR),
    ('diystyle_base_templates', '%s_templates' % SKINDIR),
    ('diystylesheet.css.dtml', '%s.dtml' % STYLESHEET),
   )

CODE_EXTENSIONS = ('.py', '.dtml', '.props')
CODE_MAPPING = (
    ('DIYPloneStyle', PRODUCTNAME),
    ('DIY Style Base', SKINNAME),
    ('DIY Style Example', SKINNAME),
    ('diystylesheet.css', STYLESHEET),
    ('David Convent <davconvent@gmail.com>', PRODUCT_AUTHOR),
    ('diystyle', SKINDIR),
   )

PUBLIC_STYLESHEETS = (
    'base.css.dtml',
    'public.css.dtml',
    'generated.css.dtml',
    'portlets.css.dtml',
    )

def log(message):
    if options.verbose:
        print >> sys.stdout, message

# Remove directory
def rmdir(dirname):
    log('Remove directory %s' % dirname)
    if os.path.isdir( dirname ):
        for filename in os.listdir(dirname):
            filepath = os.path.join(dirname, filename)
            if os.path.isfile(filepath):
                os.remove(os.path.join(dirname, filename))
            else:
                rmdir(filepath)
        os.rmdir(dirname)

# Test if the item must be kept in the new product.
def isItemKept(item):
    if item in UNWANTED_FOLDERS_AND_FILES: return False
    for unwanted in UNWANTED_FILE_EXTENSIONS:
        if item.endswith(unwanted): return False
    for unwanted in UNWANTED_FILE_PREFIXES:
        if item.startswith(unwanted): return False
    if ENABLE_PUBLIC_STYLESHEETS and item in PUBLIC_STYLESHEETS:
        return False
    return True

# Recursive copy of a folder content 
def generateDirectoryCopy(srcDirectory, dstDirectory):
    if not os.path.exists(dstDirectory):
        os.mkdir(dstDirectory)
        log('Created directory %s' % dstDirectory)
    for item in os.listdir(srcDirectory):
        if isItemKept(item):
            # Get the name of the copied item in the new product.
            dst_item = item
            for src, dst in FILE_MAPPING:
                if dst_item.endswith(src):
                    dst_item = dst_item.strip(src) + dst
            # Get source and dest paths
            src_path = os.path.join(srcDirectory, item)
            dst_path = os.path.join(dstDirectory, dst_item)
            # Read, modify and write to destination if item is a file
            if os.path.isfile(src_path):
                # Read source file
                f_src = open(src_path,'r')
                data = f_src.read()
                f_src.close()
                # Full text replacement
                if item in TEXT_FILES.keys():
                    data = TEXT_FILES[item]
                # Code subsitutions
                f,ext = os.path.splitext(item)
                if ext in CODE_EXTENSIONS or item in ('LICENSE.txt',):
                    # Remove unwanted lines
                    lines = [ line for line in data.split('\n')
                              if line.strip() not in UNWANTED_TEXT_LINES ]
                    # Remove duplicates in config
                    if item == 'config.py':
                        del lines[17:19]
                    data = '\n'.join(lines)
                    # Replace PRODUCTNAME, SKINNAME, etc.
                    for orig, dest in CODE_MAPPING:
                        data = data.replace(orig, dest)
                # Write destination file
                f_dst = open(dst_path,'w')
                f_dst.write(data)
                f_dst.close()
                log('Created file %s' % dst_path)

            # Create and copy content if item is a folder
            elif os.path.isdir(src_path):
                if not os.path.exists(dst_path):
                    os.mkdir(dst_path)
                    log('Created directory %s' % dst_path)
                generateDirectoryCopy(src_path, dst_path)

# Make sure the script doesn't blow if path contains 'DIYPloneStyle' more than
# once
last_occ = path.rindex('DIYPloneStyle')
spath = path[:last_occ] + PRODUCTNAME + path[last_occ + len('DIYPloneStyle'):]
generateDirectoryCopy(path, spath)
log('Created %s based on DIYPloneStyle.' % PRODUCTNAME)

if REPLACE_ORIGINAL:
    rmdir( os.path.join(path.strip('DIYPloneStyle'), 'DIYPloneStyle') )
    log('Removed DIYPloneStyle.')

log('%s product generated successfully.' % PRODUCTNAME)
